<!DOCTYPE html>
<html data-version="{{version}}" data-ws-url="{{ws_url}}">
  <head>
    <title>{{title}}</title>
    <meta charset="utf-8">
    <meta name="viewport" content="initial-scale=1,maximum-scale=1,user-scalable=no,width=device-width,height=device-height">

    <meta name="mobile-web-app-capable" content="yes">
    <link rel="icon" sizes="192x192" href="{{static_url('icon-192x192.png')}}">
    <link rel="icon" sizes="144x144" href="{{static_url('icon-144x144.png')}}">
    <link rel="icon" sizes="96x96" href="{{static_url('icon-96x96.png')}}">
    <link rel="icon" sizes="72x72" href="{{static_url('icon-72x72.png')}}">

    <meta name="apple-mobile-web-app-capable" content="yes">
    <link rel="apple-touch-icon" sizes="180x180" href="{{static_url('apple-touch-icon-180x180.png')}}">
    <link rel="apple-touch-icon" sizes="152x152" href="{{static_url('apple-touch-icon-152x152.png')}}">
    <link rel="apple-touch-icon" sizes="120x120" href="{{static_url('apple-touch-icon-120x120.png')}}">
    <link rel="apple-touch-icon" sizes="76x76" href="{{static_url('apple-touch-icon-76x76.png')}}">
    <link rel="apple-touch-startup-image" href="{{static_url('splash-320x480.png')}}">

    <link id="stylesheet" rel="stylesheet" href="{{static_url('css/ionic-light.min.css')}}">
    <script src="{{static_url('js/mopidy-mobile.bundle.min.js')}}"></script>
  </head>
  <body ng-app="mopidy-mobile">
    <ion-nav-bar class="bar-stable">
      <ion-nav-back-button></ion-nav-back-button>
    </ion-nav-bar>
    <ion-nav-view></ion-nav-view>
  </body>
</html>
