<ion-view view-title="{{'Logging &amp; Debugging' | translate}}">
  <ion-nav-buttons side="secondary">
    <button class="button button-clear icon mopidy-mobile-icon-more"
            ng-click="popover.show($event)"
            ng-controller="LoggingMenuCtrl"
            >
    </button>
  </ion-nav-buttons>
  <ion-content>
    <p class="padding" ng-if="records.length == 0" translate>
      No log records available.
    </p>
    <div class="list">
      <ion-item
         class = "item-icon-left"
         ng-class="{'item-text-wrap' : record.json}"
         ng-click="record.json = !record.json"
         ng-repeat="record in records"
         >
        <i class="icon" ng-class="'mopidy-mobile-icon-' + record.level"></i>
        {{record.time | date:'HH:mm:ss.sss'}}:
        <span ng-repeat="arg in record.args">
          {{record.json ? toJson(arg) : arg.toString()}}
        </span>
      </ion-item>
    </div>
  </ion-content>
</ion-view>
