<ion-tabs class="tabs-icon-top tabs-color-active-positive">
  <ion-tab title="{{'Playback' | translate}}" icon="mopidy-mobile-icon-playback" href="#/playback">
    <ion-nav-view name="playback"></ion-nav-view>
  </ion-tab>
  <ion-tab title="{{'Tracklist' | translate}}" icon="mopidy-mobile-icon-tracklist" href="#/tracklist">
    <ion-nav-view name="tracklist"></ion-nav-view>
  </ion-tab>
  <ion-tab title="{{'Library' | translate}}" icon="mopidy-mobile-icon-library" href="#/library">
    <ion-nav-view name="library"></ion-nav-view>
  </ion-tab>
  <ion-tab title="{{'Playlists' | translate}}" icon="mopidy-mobile-icon-playlists" href="#/playlists">
    <ion-nav-view name="playlists"></ion-nav-view>
  </ion-tab>
  <ion-tab title="{{'Settings' | translate}}" icon="mopidy-mobile-icon-settings" href="#/settings">
    <ion-nav-view name="settings"></ion-nav-view>
  </ion-tab>
</ion-tabs>
