<ion-view view-title="{{'Playlists' | translate}}">
  <ion-content>
    <ion-refresher
       on-refresh="refresh()"
       pulling-text="{{'Pull to refresh' | translate}}"
       >
    </ion-refresher>
    <div class="list">
      <a class="item item-icon-right"
         ng-repeat="playlist in playlists | orderBy: 'name'"
         ui-sref="main.playlists.playlist({uri: playlist.uri})"
         >
        {{playlist.name}}
        <i class="icon icon-accessory ion-chevron-right"></i>
      </a>
    </div>
  </ion-content>
</ion-view>
