<ion-view view-title="{{'Cover Art' | translate}}">
  <ion-content>
    <div class="list">
      <div class="item item-divider">
        Cover Art Sources
      </div>
      <ion-toggle class="item-input" ng-model="coverart.services.connection">
        <a href="#" ng-click="open('http://coverartarchive.org')">
          <img class="mopidy-mobile-logo" src="images/mopidy.png">
        </a>
      </ion-toggle>
      <ion-toggle class="item-input" ng-model="coverart.services.lastfm">
        <a href="#" ng-click="open('http://last.fm')">
          <img class="mopidy-mobile-logo" src="images/lastfm.gif" height="20">
        </a>
      </ion-toggle>
      <ion-toggle class="item-input" ng-model="coverart.services.coverartarchive">
        <a href="#" ng-click="open('http://coverartarchive.org')">
          <img class="mopidy-mobile-logo" src="images/coverartarchive-small.png">
        </a>
      </ion-toggle>
      <div class="item item-divider">
        Cache Settings
      </div>
      <label class="item item-input">
        <span class="input-label" translate>Cache Size</span>
        <input ng-model="coverart.cache.size" type="number">
      </label>
      <label class="item item-input">
        <button class="button" ng-click="coverart.cache.clear()" translate>
          Clear Cache
        </button>
      </label>
    </div>
  </ion-content>
</ion-view>
